@@ -613,6 +613,9 @@ class RemappedInputLine(InputLine):
         handled = True
         must_repaint = False
         text_before = self.text
+        current_word = None
+        if self.completion is not None:
+            current_word = self.current_word()
 
         if key == Key.TIMEOUT:
             must_repaint = self.on_timeout()
@@ -652,6 +655,9 @@ class RemappedInputLine(InputLine):
         else:
             handled = False
 
+        if self.completion is not None and self.current_word() != current_word:
+            self.completion.close()
+
         if text_before != self.text:
             self.on_change()
 
