@@ -1417,6 +1417,8 @@ class Program:
         self.clear_contexts = [context for context in config.list(common.SETTING_GROUP_GENERAL,
                                                                   common.SETTING_CLEAR_CONTEXT)
                                if len(context) > 0]
+        self.reuse_recurring = self.config.bool(common.SETTING_GROUP_GENERAL,
+                                                common.SETTING_REUSE_RECURRING, 'n')
         self.safe_save = self.config.bool(common.SETTING_GROUP_GENERAL, common.SETTING_SAFE_SAVE)
         self.delegate_marker = self.config.get(common.SETTING_GROUP_GENERAL, common.SETTING_DELEG_MARKER).strip()
         self.delegate_to = self.config.get(common.SETTING_GROUP_GENERAL, common.SETTING_DELEG_TO).strip()
@@ -1523,7 +1525,7 @@ class Program:
         taskindex = self.window.taskModel.ensure_up_to_date(taskindex)
         if taskindex is not None:
             task = taskindex.data(TASK_ROLE)
-            utils.toggle_done(task, self.clear_contexts)
+            utils.toggle_done(task, self.clear_contexts, self.reuse_recurring, self.safe_save)
             task.todotxt.save(safe=self.safe_save)
             self.window.taskModel.setData(taskindex, task)
 
